require("StepReg") || stop("unable to load StepReg")
require("testthat") || stop("unable to load testthat")
require("survival") || stop("unable to load survival")
test_check("StepReg")
